
## References & Resources
 - [Cython C libraries usage](https://cython.readthedocs.io/en/latest/src/tutorial/clibraries.html)
 - [Cython & GIL](https://cython.readthedocs.io/en/latest/src/userguide/nogil.html)
